@@ -6,6 +6,8 @@ use PRANG::Graph;
 use XML::SRS::Contact::Address;
 use XML::SRS::Contact::PSTN;
 
+use Moose::Util::TypeConstraints;
+
 # attributes
 has_attr 'name' =>
 	is => 'ro',
@@ -27,6 +29,7 @@ has_element 'postal_address_filter' =>
 	isa => 'XML::SRS::Contact::Address',
 	xml_nodeName => 'PostalAddressFilter',
 	xml_required => 0,
+	coerce => 1,
 	;
 
 has_element 'phone' =>
@@ -34,16 +37,26 @@ has_element 'phone' =>
 	isa => 'XML::SRS::Contact::PSTN',
 	xml_nodeName => 'Phone',
 	xml_required => 0,
+	coerce => 1,
 	;
 
-has_element 'Fax' =>
+has_element 'fax' =>
 	is => 'ro',
 	isa => 'XML::SRS::Contact::PSTN',
 	xml_nodeName => 'Fax',
 	xml_required => 0,
+	coerce => 1,
 	;
 
-sub root_element { 'ContactFilter' }
+coerce __PACKAGE__
+	=> from 'HashRef'
+	=> via {
+    	__PACKAGE__->new(
+    		%{$_[0]},
+    	);
+    };
+
+sub root_element {'ContactFilter'}
 
 with 'XML::SRS::Node';
 
