@@ -6,15 +6,14 @@ use PRANG::Graph;
 use PRANG::XMLSchema::Types;
 use XML::SRS::Types;
 use Moose::Util::TypeConstraints;
+use PRANG::Coerce;
+
+use XML::SRS::FieldList;
+use XML::SRS::Server::Filter::List;
+use XML::SRS::Contact::Filter;
+use XML::SRS::Date::Range;
 
 # attributes
-has_attr 'query_id' =>
-	is => 'ro',
-	isa => 'XML::SRS::UID',
-	xml_name => 'QryId',
-	xml_required => 0,
-	;
-
 has_attr 'status' =>
 	is => 'ro',
 	isa => 'XML::SRS::RegDomainStatus',
@@ -44,14 +43,14 @@ has_attr 'registrant_ref' =>
 	;
 
 has_attr 'max_results' =>
-	is => 'ro',
+	is => 'rw',
 	isa => 'XML::SRS::Number',
 	xml_name => 'MaxResults',
 	xml_required => 0,
 	;
 
 has_attr 'skip_results' =>
-	is => 'ro',
+	is => 'rw',
 	isa => 'XML::SRS::Number',
 	xml_name => 'SkipResults',
 	xml_required => 0,
@@ -67,16 +66,18 @@ has_attr 'count_results' =>
 # elements
 has_element 'domain_name_filter' =>
 	is => 'ro',
-	isa => 'ArrayRef[Str]',
+	isa => 'PRANG::Coerce::ArrayRefOfStrs',
 	xml_nodeName => 'DomainNameFilter',
 	xml_required => 0,
+	coerce => 1,
 	;
 
 has_element 'name_server_filter' =>
 	is => 'ro',
-	isa => 'XML::SRS::Server::Filter',
+	isa => 'XML::SRS::Server::Filter::List',
 	xml_nodeName => 'NameServerFilter',
 	xml_required => 0,
+	coerce => 1,
 	;
 
 has_element 'registrant_contact_filter' =>
@@ -84,6 +85,7 @@ has_element 'registrant_contact_filter' =>
 	isa => 'XML::SRS::Contact::Filter',
 	xml_nodeName => 'RegistrantContactFilter',
 	xml_required => 0,
+	coerce => 1,
 	;
 
 has_element 'admin_contact_filter' =>
@@ -91,6 +93,7 @@ has_element 'admin_contact_filter' =>
 	isa => 'XML::SRS::Contact::Filter',
 	xml_nodeName => 'AdminContactFilter',
 	xml_required => 0,
+	coerce => 1,
 	;
 
 has_element 'technical_contact_filter' =>
@@ -98,6 +101,7 @@ has_element 'technical_contact_filter' =>
 	isa => 'XML::SRS::Contact::Filter',
 	xml_nodeName => 'TechnicalContactFilter',
 	xml_required => 0,
+	coerce => 1,
 	;
 
 has_element 'result_date_range' =>
@@ -105,6 +109,7 @@ has_element 'result_date_range' =>
 	isa => 'XML::SRS::Date::Range',
 	xml_required => 0,
 	xml_nodeName => 'ResultDateRange',
+	coerce => 1,
 	;
 
 has_element 'search_date_range' =>
@@ -112,6 +117,7 @@ has_element 'search_date_range' =>
 	isa => 'XML::SRS::Date::Range',
 	xml_required => 0,
 	xml_nodeName => 'SearchDateRange',
+	coerce => 1,
 	;
 
 has_element 'changed_in_date_range' =>
@@ -119,6 +125,7 @@ has_element 'changed_in_date_range' =>
 	isa => 'XML::SRS::Date::Range',
 	xml_required => 0,
 	xml_nodeName => 'ChangedInDateRange',
+	coerce => 1,
 	;
 
 has_element 'registered_date_range' =>
@@ -126,6 +133,7 @@ has_element 'registered_date_range' =>
 	isa => 'XML::SRS::Date::Range',
 	xml_required => 0,
 	xml_nodeName => 'RegisteredDateRange',
+	coerce => 1,
 	;
 
 has_element 'locked_date_range' =>
@@ -133,6 +141,7 @@ has_element 'locked_date_range' =>
 	isa => 'XML::SRS::Date::Range',
 	xml_required => 0,
 	xml_nodeName => 'LockedDateRange',
+	coerce => 1,
 	;
 
 has_element 'cancelled_date_range' =>
@@ -140,6 +149,7 @@ has_element 'cancelled_date_range' =>
 	isa => 'XML::SRS::Date::Range',
 	xml_required => 0,
 	xml_nodeName => 'CancelledDateRange',
+	coerce => 1,
 	;
 
 has_element 'billed_until_date_range' =>
@@ -147,6 +157,7 @@ has_element 'billed_until_date_range' =>
 	isa => 'XML::SRS::Date::Range',
 	xml_required => 0,
 	xml_nodeName => 'BilledUntilDateRange',
+	coerce => 1,
 	;
 
 has_element 'audit_text_filter' =>
@@ -168,9 +179,10 @@ has_element 'field_list' =>
 	isa => 'XML::SRS::FieldList',
 	xml_required => 0,
 	xml_nodeName => 'FieldList',
+	coerce => 1,
 	;
 
-sub root_element { 'DomainDetailsQry' }
+sub root_element {'DomainDetailsQry'}
 with 'XML::SRS::Query';
 
 1;
