@@ -42,30 +42,39 @@ has_element 'contact_public' =>
 	is => "rw",
 	isa => "XML::SRS::Contact",
 	xml_nodeName => "RegistrarPublicContact",
+	coerce => 1,
+	required => 1,
 	;
 
 has_element 'contact_private' =>
 	is => "rw",
 	isa => "XML::SRS::Contact",
 	xml_nodeName => "RegistrarSRSContact",
+	coerce => 1,
+	required => 1,
 	;
 
 has_element 'contact_technical' =>
 	is => "rw",
 	isa => "XML::SRS::Contact",
 	xml_nodeName => "DefaultTechnicalContact",
+	coerce => 1,
+	required => 1,
 	;
 
+use XML::SRS::Keyring;
 has_element 'keyring' =>
 	is => "rw",
 	isa => "XML::SRS::Keyring",
 	xml_nodeName => "EncryptKeys",
+	required => 1,
 	;
 
 has_element 'epp_auth' =>
 	is => "rw",
 	isa => "XML::SRS::Password",
 	xml_nodeName => "EPPAuth",
+	coerce => 1,
 	predicate => "has_epp_auth",
 	;
 
@@ -90,7 +99,7 @@ has_element 'audit' =>
 	predicate => "has_audit",
 	;
 
-sub root_element { "Registrar" }
+sub root_element {"Registrar"}
 with 'XML::SRS::ActionResponse';
 
 1;
