@@ -4,34 +4,41 @@ package XML::SRS::Time;
 use Moose::Role;
 use PRANG::Graph;
 use Moose::Util::TypeConstraints;
-use MooseX::Method::Signatures;
+use MooseX::Params::Validate;
 
 BEGIN{
-subtype 'XML::SRS::Time::Hour'
-	=> as "Int",
-	=> where {
+	subtype 'XML::SRS::Time::Hour'
+		=> as "Int",
+		=> where {
 		$_ >= 0 and $_ <= 23;
-	};
-subtype 'XML::SRS::Time::Sexagesimal'
-	=> as "Int",
-	=> where {
+		};
+	subtype 'XML::SRS::Time::Sexagesimal'
+		=> as "Int",
+		=> where {
 		$_ >= 0 and $_ <= 59;
-	};
-subtype 'XML::SRS::Time::TZOffset'
-	=> as "Str",
-	=> where {
+		};
+	subtype 'XML::SRS::Time::TZOffset'
+		=> as "Str",
+		=> where {
 		m{^[-+][\s\d]?\d(?::?\d\d)?$};
 
-	};
+		};
 
-subtype 'XML::SRS::Time::hms'
-	=> as "Str",
-	=> where {
+	subtype 'XML::SRS::Time::hms'
+		=> as "Str",
+		=> where {
 		m{^(\d{1,2}):(\d{1,2}):(\d{1,2})$};
-	};
+		};
 }
 
-method buildargs_time($inv: XML::SRS::Time::hms $hms, Maybe[XML::SRS::Time::TZOffset] $offset?) {
+sub buildargs_time {
+      my $inc = shift;
+      my ( $hms, $offset ) = pos_validated_list(
+          \@_,
+          { isa => 'XML::SRS::Time::hms' },
+          { isa => 'Maybe[XML::SRS::Time::TZOffset]', optional => 1 },
+      );    
+    
 	my @buildargs;
 	if (defined $offset) {
 		push @buildargs, tz_offset => $offset;
