@@ -2,7 +2,7 @@
 package XML::SRS::Version;
 use Moose::Role;
 use PRANG::Graph;
-use MooseX::Method::Signatures;
+use MooseX::Params::Validate;
 
 has_attr "major" =>
 	is => "rw",
@@ -23,12 +23,18 @@ has "version" =>
 	isa => "Str",
 	lazy => 1,
 	default => sub {
-		my $self = shift;
-		$self->major.".".$self->minor;
+	my $self = shift;
+	$self->major.".".$self->minor;
 	},
 	;
 
-method buildargs_version( $inv: Str $version ) {
+sub buildargs_version {
+      my $inv = shift;
+      my ( $version ) = pos_validated_list(
+          \@_,
+          { isa => 'Str' },
+      );    
+    
 	$version = $XML::SRS::PROTOCOL_VERSION
 		if $version eq "auto";
 	my ($vmaj, $vmin) = split /\./, $version;
